==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragEndEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragEndEventArgsDescriptionMetadata, _super);
    function WebPaneDragEndEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragEndEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
            WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPaneDragEndEventArgsDescriptionMetadata.a);
        WebDockManagerPaneDescriptionMetadata.d(a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
        a.item("SourcePane", "ExportedType:WebDockManagerPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
    };
    WebPaneDragEndEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragEndEventArgsDescriptionMetadata.b(a);
        a.aa("WebPaneDragEndEventArgs", function () { return new WebPaneDragEndEventArgsDescription(); });
        a.z("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragEndEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPaneDragEndEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragEndEventArgsDetailDescriptionMetadata } from "./WebPaneDragEndEventArgsDetailDescriptionMetadata";
import { WebPaneDragEndEventArgsDescription } from "./WebPaneDragEndEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragEndEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragEndEventArgsDescriptionMetadata, _super);
    function WebPaneDragEndEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragEndEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragEndEventArgsDescriptionMetadata.a == null) {
            WebPaneDragEndEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragEndEventArgsDescriptionMetadata.c(WebPaneDragEndEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragEndEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPaneDragEndEventArgsDescriptionMetadata.a);
        WebPaneDragEndEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragEndEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneDragEndEventArgsDetail");
    };
    WebPaneDragEndEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragEndEventArgsDescriptionMetadata.b(a);
        a.ac("WebPaneDragEndEventArgs", function () { return new WebPaneDragEndEventArgsDescription(); });
        a.ab("WebPaneDragEndEventArgs", WebPaneDragEndEventArgsDescriptionMetadata.a);
    };
    WebPaneDragEndEventArgsDescriptionMetadata.$t = markType(WebPaneDragEndEventArgsDescriptionMetadata, 'WebPaneDragEndEventArgsDescriptionMetadata');
    WebPaneDragEndEventArgsDescriptionMetadata.a = null;
    return WebPaneDragEndEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragEndEventArgsDescriptionMetadata };
